{% extends "base-site.html" %}

{% block title %} Credits {% endblock %} 

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

    <div class="row">
        <div class="col-md-12">
            <div class="card card-profile">
                <div class="card-body">
                    <h6 class="card-category text-gray">Dashboard Credits</h6>
                    <h4 class="card-title">
                        {% if redirect %}
                            This instance of Red Discord Bot is owned by {{ owner }}. <br />
                        {% endif %}
                        The base template for this dashboard was created by <a href="https://appseed.us/app-generator">AppSeed Web App Generator</a>, protected under <a href="https://github.com/app-generator/flask-black-dashboard/blob/master/LICENSE.md">MIT License</a>.<br/>
                        The dashboard was edited and recoded to work with Red Discord Bot by <a href="https://github.com/NeuroAssassin">Neuro Assassin#4779</a>, protected under <a href="https://github.com/NeuroAssassin/Toxic-Cogs/blob/master/LICENSE">MIT License</a>.<br />
                        This dashboard was made for <a href="https://github.com/Cog-Creators/Red-DiscordBot">Red Discord Bot</a>, a multifunctional, fully modular Discord bot, created By Twentysix, made great by many.  Red Discord Bot is protected under <a href="https://github.com/Cog-Creators/Red-DiscordBot/blob/V3/develop/LICENSE">GNU General Public License v3.0</a>.
                    </h4>
                </div>
                <div class="card-footer">
                    Dashboard Version {{ version }}
                </div>
            </div>
        </div>
    </div>
    
{% endblock content %}

<!-- Specific Page JS goes HERE  -->
{% block javascripts %}{% endblock javascripts %}
