

    <div class="sidebar">
      <div class="sidebar-wrapper">
        <div class="logo">
          <a class="simple-text logo-mini clickable dontcolor" target="_blank">
            <i class="tim-icons icon-atom"></i>
          </a>
          <a class="simple-text logo-normal clickable dontcolor" target="_blank">
            Dashboard
          </a>
        </div>

        {% if session.get("id") %}
        <ul class="nav">
          <li id="navindex">
            <a href="/index">
              <i class="tim-icons icon-chart-pie-36"></i>
              <p>Home</p>
            </a>
          </li>
          <li id="navcommands">
            <a href="/commands">
              <i class="tim-icons icon-molecule-40"></i>
              <p>Commands</p>
            </a>
          </li>
          <li id="navdashboard">
            <a href="/dashboard">
              <i class="tim-icons icon-controller"></i>
              <p>Dashboard</p>
            </a>
          </li>
          <li id="navcredits">
            <a href="/credits">
              <i class="tim-icons icon-book-bookmark"></i>
              <p>Credits</p>
            </a>
          </li>
          <li>
            <a href={{ url_for('base_blueprint.logout') }} >
              <i class="tim-icons icon-user-run"></i>
              <p>Logout</p>
            </a>
          </li>
        </ul>
        {% else %}
        <ul class="nav">
          <li id="navindex">
            <a href="/index">
              <i class="tim-icons icon-chart-pie-36"></i>
              <p>Home</p>
            </a>
          </li>
          {% if redirect %}
            <li id="navcommands">
              <a href="/commands">
                <i class="tim-icons icon-molecule-40"></i>
                <p>Commands</p>
              </a>
            </li>
          {% endif %}
          <li id="navcredits">
            <a href="/credits">
              <i class="tim-icons icon-book-bookmark"></i>
              <p>Credits</p>
            </a>
          </li>
          <li id="navlogin">
            <a href="/login">
              <i class="tim-icons icon-key-25"></i>
              <p>Login</p>
            </a>
          </li>
        </ul>
        {% endif %}
        
      </div>
    </div>
