{% extends "base-site.html" %}

{% block title %} Page 404 {% endblock %} 

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

    <div class="row">
        <div class="col-md-12">
            <div class="card card-profile">
                <div class="card-body">
                    <h6 class="card-category text-gray">Oops!</h6>
                    <h4 class="card-title">
                        Looks like you're not allowed to access that page... Strange...
                    </h4>
                    <a href="/" class="btn btn-primary btn-round">Home</a>
                </div>
            </div>
        </div>
    </div>


{% endblock content %}

<!-- Specific Page JS goes HERE  -->
{% block javascripts %}{% endblock javascripts %}
